==> django-email-confirm-la-0.1.0.tar.gz: django-email-confirm-la-0.1.0/setup.py <==
#!/usr/bin/env python

import os
import sys

from setuptools import find_packages, setup


if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist upload')
    sys.exit()

version = __import__('email_confirm_la').get_version()

long_description = open('README.rst').read()

license = open('LICENSE').read()

requirements_lines = [line.strip() for line in open('requirements.txt').readlines()]
install_requires = list(filter(None, requirements_lines))

setup(
    name='django-email-confirm-la',
    version=version,
    description='Django email confirmation for any Model and any Field.',
    long_description=long_description,
    keywords='django,email,confirm,confirmation',
    author='Vinta Chen',
    author_email='vinta.chen@gmail.com',
    url='https://github.com/vinta/django-email-confirm-la',
    license=license,
    install_requires=install_requires,
    include_package_data=True,
    packages=find_packages(),
    zip_safe=False,
    classifiers=(
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Topic :: Communications :: Email',
        'Topic :: Internet',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
    ),
)

==> django-email-confirm-la-0.2.0.tar.gz: django-email-confirm-la-0.2.0/setup.py <==
#!/usr/bin/env python

import os
import sys

from setuptools import find_packages, setup


if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist upload')
    sys.exit()

version = __import__('email_confirm_la').get_version()

long_description = open('README.rst').read() + '\n\n' + open('HISTORY.rst').read()

license = open('LICENSE').read()

requirements_lines = [line.strip() for line in open('requirements.txt').readlines()]
install_requires = list(filter(None, requirements_lines))

setup(
    name='django-email-confirm-la',
    version=version,
    description='Django email confirmation for any Model and any Field.',
    long_description=long_description,
    keywords='django, email, confirm, confirmation, content type',
    author='Vinta Chen',
    author_email='vinta.chen@gmail.com',
    url='https://github.com/vinta/django-email-confirm-la',
    license=license,
    install_requires=install_requires,
    include_package_data=True,
    packages=find_packages(),
    zip_safe=False,
    classifiers=(
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Topic :: Communications :: Email',
        'Topic :: Internet',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
    ),
)
